pub enum ClientError {
PacketWrite(PacketWriteError),
PacketRead(PacketReadError),
ClientState(ClientStateError),
TimeoutOnResponsePacket,
Disconnected(DisconnectReasonCode),
EventHandler(EventHandlerError),
EmptyTopicNameWithAliasesDisabled,
}Expand description
Client error
Variants
PacketWrite(PacketWriteError)
PacketRead(PacketReadError)
ClientState(ClientStateError)
TimeoutOnResponsePacket
Disconnected(DisconnectReasonCode)
EventHandler(EventHandlerError)
EmptyTopicNameWithAliasesDisabled
Client received an empty topic name when it has disabled topic aliases This indicates a server error, client should disconnect, it may send a Disconnect with DisconnectReasonCode::TopicAliasInvalid, on the assumption that the packet also had some topic alias specified.