ConnectionEmbedded

Struct ConnectionEmbedded 

pub struct ConnectionEmbedded<T>
where T: Read + Write + ReadReady,
{ /* private fields */ }
Contains an instance of T with Read, Write and ReadReady. We implement Connection for this rather than T directly to avoid issues with conflicting implementations of external types T that could in future add Read, Write and ReadReady

Implementations

Source

impl<T> ConnectionEmbedded<T>
where T: Read + Write + ReadReady,

pub fn new(inner: T) -> Self

Create a new adapter

pub fn into_inner(self) -> T

Consume the adapter, returning the inner object.

pub fn inner(&self) -> &T

Borrow the inner object.

pub fn inner_mut(&mut self) -> &mut T

Mutably borrow the inner object.