pub enum PacketWriteError {
Overflow,
NullCharacterInString,
VariableByteIntegerTooLarge,
DataTooLarge,
StringTooLarge,
ConnectionSend,
}Variants
Overflow
On attempt to put data that will not fit in buffer
NullCharacterInString
On attempt to put a string containing a null character (which is not valid in an MQTT message)
VariableByteIntegerTooLarge
On attempt to put a u32 value as a variable byte integer, where the value is too large to encode
DataTooLarge
On attempt to put binary data with too many bytes to encode
StringTooLarge
On attempt to put a string where the encoded form is too many bytes to encode
ConnectionSend
Failure to send via connection